@@ -109,14 +109,16 @@ class MqttAsyncClient():
                                   options.will['qos'],
                                   options.will['retained'])
         if self._client:
-            if clientCertFile:
+            if options._caFile:
                 port = 8883 # Port with ssl
                 self._client.tls_set(options._caFile,  # CA certificate
-                                    certfile=clientCertFile,  # Client certificate
-                                    keyfile=clientKeyFile,  # Client private key
-                                    tls_version=tlsVersion,  # ssl.PROTOCOL_TLSv1, ssl.PROTOCOL_TLSv1_2
-                                    ciphers=None)      # None, 'ALL', 'TLSv1.2', 'TLSv1.0'
+                                     certfile=clientCertFile,   # Client certificate
+                                     keyfile=clientKeyFile,     # Client private key
+                                     tls_version=tlsVersion,    # ssl.PROTOCOL_TLSv1, ssl.PROTOCOL_TLSv1_2
+                                     ciphers=None)              # None, 'ALL', 'TLSv1.2', 'TLSv1.0'
                 self._client.tls_insecure_set(True)  # True: No verification of the server hostname in the server certificate
+            else:
+                self.log.error('No CA file provided. Connection attempt likely to fail!')
 
             # Check if username and password is provided
             if options._username:
